@@ -525,6 +525,8 @@ def rerun_tests():
             numruns = numruns+1
 
 def getresults():
+    if run_id == "":
+        exit()
     echo("getting results")
     headers = {
     'token': apikey,
@@ -723,9 +725,8 @@ def runtestswithappsurify(*args):
         argv = args[0]
         if type(argv) == tuple:
             argv = argv[0]
-    except: # catch *all* exceptions
-        e = sys.exc_info()[0]
-        print( "Error: %s" % e )
+    except Exception as e:
+        print(e)
     c=0
     print("===================================")
     if len(argv) > 1 :
@@ -1017,8 +1018,8 @@ def runtestswithappsurify(*args):
         executetests = "false"
         testseparator="|"
         reporttype="file"
-        startrunspecific="vstest.console.exe /resultsfile:'" + testtemplatearg1 + "' /testcontainer:'" + testtemplatearg2 + "'" + "/TestCaseFilter:\"("
-        endrunspecific="\")"
+        startrunspecific="vstest.console.exe /resultsfile:'" + testtemplatearg1 + "' /testcontainer:'" + testtemplatearg2 + "'" + "/TestCaseFilter:\""
+        endrunspecific="\""
         postfixtest=""
         prefixtest="Name="
         startrunall="vstest.console.exe /resultsfile:'" + testtemplatearg1 + "' /testcontainer:'" + testtemplatearg2 + "'"
@@ -1327,9 +1328,8 @@ def runtestswithappsurify(*args):
 
     try:
         os.environ["TESTSTORUN"] = testsrun
-    except: # catch *all* exceptions
-        e = sys.exc_info()[0]
-        print( "Error: %s" % e )
+    except Exception as e:
+        print(e)
     
 
     if testsrun == "":
@@ -1339,6 +1339,10 @@ def runtestswithappsurify(*args):
 
     #print("tests " + os.environ.get('TESTSTORUN'))
     #print("##vso[task.setvariable variable=TestsToRun;isOutput=true]"+testsrun)
+    if testtemplate == "azure dotnet":
+        print (f'##vso[task.setvariable variable=TestsToRun]{testsrun}')
+    #print("##vso[task.setvariable variable=BuildVersion;]998")
+
 
 
     if failfast == "false" and rerun == "true" and teststorun != "none":
